@@ -28,6 +28,8 @@
 
 #define QT_FEATURE_cxx2b -1
 
+#define QT_FEATURE_cxx2c -1
+
 #define QT_FEATURE_reduce_relocations -1
 
 #define QT_FEATURE_signaling_nan 1
@@ -36,6 +38,8 @@
 
 #define QT_FEATURE_wasm_exceptions -1
 
+#define QT_FEATURE_wasm_jspi -1
+
 #define QT_FEATURE_zstd 1
 
 #define QT_FEATURE_thread 1
@@ -52,14 +56,16 @@
 
 #define QT_FEATURE_opensslv30 1
 
+#define QT_FEATURE_test_gui 1
 
-#define QT_VERSION_STR "6.8.2"
+
+#define QT_VERSION_STR "6.10.0"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 8
+#define QT_VERSION_MINOR 10
 
-#define QT_VERSION_PATCH 2
+#define QT_VERSION_PATCH 0
 
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #define QT_LARGEFILE_SUPPORT 64
@@ -67,3 +73,4 @@
 #define QT_COMPILER_SUPPORTS_NEON 1
 #define QT_NO_WIDGETS
 #define QT_LINKED_OPENSSL
+#define QT_GUI_TEST 1
